# LAMPy

Lampy (**L**ight and fast **A**ladyn data **M**anipulation in **Py**thon) is a python package that provides modules to access and plot ALaDyn output files.

The idea behind its development is to provide a selfconsistent and portable environment, allowing any user to elaborate ALaDyn simulations results.
Other possibility are also available (C++ data converters, gnuplot analysis, IDL routines), but they are mostly single file analyzers. With LAMPy, we would like to offer a fast and modern way to perform a complete *inline* data analysis, taking advantage of the simplicity of the Python language which requires a minimum effort even for a beginner user. 

## Package

LAMPy is still under development, which means problems may occur for some untested output configuration.